# pydynu

A Python wrapper for Dynu ddns API.

## Quickstart
- `pip install pydynu` or `pip3 install pydynu`
- Go to your [API Credential](https://www.dynu.com/ControlPanel/APICredentials) page and generate a new API key.
- Copy the key inside an `api.key` file.
- Use the API to your needs.


### TODO

- Add support for OAuth keys
- Tests
- More examples
